@@ -20,32 +20,27 @@ import asyncio
 import json
 import locale
 import logging
+import pathlib
 import re
 import sys
 from typing import List, Optional
 
 from .controller import Controller
+from .exceptions import HomeKitException
 from .model.characteristics import CharacteristicsTypes
 from .model.services import ServicesTypes
 
 logger = logging.getLogger(__name__)
 
-
-def pin_from_parameter(number):
-    def tmp():
-        return number
-
-    return tmp
+XDG_DATA_HOME = pathlib.Path.home() / ".local" / "share"
+DEFAULT_PAIRING_FILE = XDG_DATA_HOME / "aiohomekit" / "pairing.json"
 
 
 def pin_from_keyboard():
-    def tmp():
-        read_pin = ""
-        while re.match(r"^\d{3}-\d{2}-\d{3}$", read_pin) is None:
-            read_pin = input("Enter device pin (XXX-YY-ZZZ): ")
-        return read_pin
-
-    return tmp
+    read_pin = ""
+    while re.match(r"^\d{3}-\d{2}-\d{3}$", read_pin) is None:
+        read_pin = input("Enter device pin (XXX-YY-ZZZ): ")
+    return read_pin
 
 
 def setup_logging(level: None) -> None:
@@ -134,23 +129,31 @@ async def pair_ip(args):
         print(f'"{args.alias}" is a already known alias')
         return False
 
-    if args.pin:
-        pin_function = pin_from_parameter(args.pin)
-    else:
-        pin_function = pin_from_keyboard()
-
     discovery = await controller.find_ip_by_device_id(args.device)
 
     try:
         finish_pairing = await discovery.start_pairing(args.alias)
-        pairing = await finish_pairing(pin_function())
-        await pairing.list_accessories_and_characteristics()
-        controller.save_data(args.file)
-        print(f'Pairing for "{args.alias}" was established.')
-    except Exception:
-        logging.exception("Error whilst pairing")
+    except HomeKitException as e:
+        print(str(e))
         return False
 
+    pin = args.pin if args.pin else pin_from_keyboard()
+
+    try:
+        pairing = await finish_pairing(pin)
+    except HomeKitException as e:
+        print(str(e))
+        return False
+
+    try:
+        await pairing.list_accessories_and_characteristics()
+    except HomeKitException as e:
+        print(str(e))
+        return False
+
+    controller.save_data(args.file)
+
+    print(f'Pairing for "{args.alias}" was established.')
     return True
 
 
@@ -391,7 +394,9 @@ async def get_events(args):
     while True:
         # get the data
         try:
-            data = await pairing.get_characteristics(characteristics,)
+            data = await pairing.get_characteristics(
+                characteristics,
+            )
             handler(data)
         except Exception:
             logging.exception("Error whilst fetching /accessories")
@@ -406,8 +411,9 @@ def setup_parser_for_pairing(parser: ArgumentParser) -> None:
     parser.add_argument(
         "-f",
         action="store",
-        required=True,
+        required=False,
         dest="file",
+        default=DEFAULT_PAIRING_FILE,
         help="File with the pairing data",
     )
     parser.add_argument(
@@ -418,7 +424,10 @@ def setup_parser_for_pairing(parser: ArgumentParser) -> None:
 async def main(argv: Optional[List[str]] = None) -> None:
     argv = argv or sys.argv[1:]
 
-    parser = argparse.ArgumentParser()
+    parser = argparse.ArgumentParser(
+        description="aiohomekitctl",
+        formatter_class=argparse.RawDescriptionHelpFormatter,
+    )
     parser.add_argument(
         "--adapter",
         action="store",
@@ -429,11 +438,13 @@ async def main(argv: Optional[List[str]] = None) -> None:
     add_log_arguments(parser)
 
     subparsers = parser.add_subparsers(
-        title="subcommands", description="valid subcommands", help="additional help"
+        title="available commands", metavar="command [options ...]"
     )
 
     # discover_ip
-    discover_parser = subparsers.add_parser("discover_ip")
+    discover_parser = subparsers.add_parser(
+        "discover-ip", help="Find HomeKit devices accessible by LAN/WiFi"
+    )
     discover_parser.set_defaults(func=discover_ip)
     discover_parser.add_argument(
         "-t",
@@ -453,7 +464,9 @@ async def main(argv: Optional[List[str]] = None) -> None:
     )
 
     # pair_ip
-    pair_parser = subparsers.add_parser("pair_ip")
+    pair_parser = subparsers.add_parser(
+        "pair-ip", help="Pair with a HomeKit device accessible on your LAN/WiFi"
+    )
     pair_parser.set_defaults(func=pair_ip)
     setup_parser_for_pairing(pair_parser)
     pair_parser.add_argument(
@@ -472,7 +485,10 @@ async def main(argv: Optional[List[str]] = None) -> None:
     )
 
     # get_accessories - return all characteristics of all services of all accessories.
-    get_accessories_parser = subparsers.add_parser("get_accessories")
+    get_accessories_parser = subparsers.add_parser(
+        "accessories",
+        help="List all accessories, services and characteristics for a paired device",
+    )
     get_accessories_parser.set_defaults(func=get_accessories)
     setup_parser_for_pairing(get_accessories_parser)
     get_accessories_parser.add_argument(
@@ -485,7 +501,10 @@ async def main(argv: Optional[List[str]] = None) -> None:
     )
 
     # get_characteristics - get only requested characteristics
-    get_char_parser = subparsers.add_parser("get_characteristics")
+    get_char_parser = subparsers.add_parser(
+        "get",
+        help="Read an up to date value from a characteristic of a paired device",
+    )
     get_char_parser.set_defaults(func=get_characteristics)
     setup_parser_for_pairing(get_char_parser)
     get_char_parser.add_argument(
@@ -525,7 +544,9 @@ async def main(argv: Optional[List[str]] = None) -> None:
     )
 
     # put_characteristics - set characteristics values
-    put_char_parser = subparsers.add_parser("put_characteristics")
+    put_char_parser = subparsers.add_parser(
+        "put", help="Write to a characteristic of a paired device"
+    )
     put_char_parser.set_defaults(func=put_characteristics)
     setup_parser_for_pairing(put_char_parser)
     put_char_parser.add_argument(
@@ -537,13 +558,30 @@ async def main(argv: Optional[List[str]] = None) -> None:
         help="Use aid.iid value to change the value. Repeat to change multiple characteristics.",
     )
 
+    get_events_parser = subparsers.add_parser(
+        "watch", help="Monitor changes to characteristics on this device"
+    )
+    get_events_parser.set_defaults(func=get_events)
+    setup_parser_for_pairing(get_events_parser)
+    get_events_parser.add_argument(
+        "-c",
+        action="append",
+        required=True,
+        dest="characteristics",
+        help="Read characteristics, multiple characteristics can be given by repeating the option",
+    )
+
     # list_pairings - list all pairings
-    list_pairings_parser = subparsers.add_parser("list_pairings")
+    list_pairings_parser = subparsers.add_parser(
+        "list-pairings", help="List all pairings from a paired device"
+    )
     list_pairings_parser.set_defaults(func=list_pairings)
     setup_parser_for_pairing(list_pairings_parser)
 
     # remove_pairing - remove sub pairing
-    remove_pairing_parser = subparsers.add_parser("remove_pairing")
+    remove_pairing_parser = subparsers.add_parser(
+        "remove-pairing", help="Remove a subpairing from a paired device"
+    )
     remove_pairing_parser.set_defaults(func=remove_pairing)
     setup_parser_for_pairing(remove_pairing_parser)
     remove_pairing_parser.add_argument(
@@ -555,31 +593,30 @@ async def main(argv: Optional[List[str]] = None) -> None:
     )
 
     # unpair - completely unpair the device
-    unpair_parser = subparsers.add_parser("unpair")
+    unpair_parser = subparsers.add_parser(
+        "unpair", help="Completely unpair this device"
+    )
     unpair_parser.set_defaults(func=unpair)
     setup_parser_for_pairing(unpair_parser)
 
-    get_events_parser = subparsers.add_parser("get_events")
-    get_events_parser.set_defaults(func=get_events)
-    setup_parser_for_pairing(get_events_parser)
-    get_events_parser.add_argument(
-        "-c",
-        action="append",
-        required=True,
-        dest="characteristics",
-        help="Read characteristics, multiple characteristics can be given by repeating the option",
-    )
-
     args = parser.parse_args(argv)
 
     setup_logging(args.loglevel)
 
+    if not hasattr(args, "func"):
+        parser.print_help()
+        sys.exit(1)
+
     if not await args.func(args):
         sys.exit(1)
 
 
-if __name__ == "__main__":
+def sync_main():
     try:
         asyncio.run(main())
     except KeyboardInterrupt:
         pass
+
+
+if __name__ == "__main__":
+    sync_main()
